<?php
/**
 * @version     tmpl/slider.php - 18/04/2025
 * @copyright   Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
 * @email       info@ScorpionComputers.nl
 *
 * Slider Template for Scorpion Sponsors Module
 *
 * @var   array   $sponsors      An array of sponsor objects.
 * @var   object  $params        The module parameters.
 * @var   object  $module        The module object.
 * @var   string  $layout        The layout being rendered.
 * @var   ScorpionSponsorsHelper $helper The helper object.
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Uri\Uri;

// Optional: Get module class suffix
$moduleclass_sfx = htmlspecialchars($params->get('moduleclass_sfx') ?? '');

$helper = new ScorpionSponsorsHelper($params,$module->id);
$helper->addBasicCSS();
// $sponsors = $helper->getSponsors();

// Add SwiperJS assets (this should ideally be called from the helper based on selected layout)
$helper->addSliderAssets(); // Example: You'll need to implement this in helper.php

?>
<div id="scs-sponsors-slider-<?php echo $module->id; ?>" class="scs-sponsors-tmpl-slider scs-sponsors-<?php echo $moduleclass_sfx; ?>">
    <!-- Slider main container -->
    <div class="swiper scs-swiper-container">
        <!-- Additional required wrapper -->
        <div class="swiper-wrapper">
            <!-- Slides -->
            <?php foreach ($sponsors as $sponsor) : ?>
                <div class="swiper-slide sponsor-item">
                    <?php if ($sponsor->isLinkValid) : ?>
                        <a href="<?php echo $sponsor->link; ?>" target="_blank" rel="noopener noreferrer">
                    <?php endif; ?>

                    <?php if ($sponsor->imageSrc) : ?>
                        <img src="<?php echo $sponsor->imageSrc; ?>" alt="<?php echo htmlspecialchars($sponsor->name, ENT_QUOTES, 'UTF-8'); ?>" loading="lazy">
                    <?php else : ?>
                        <span><?php echo htmlspecialchars($sponsor->name, ENT_QUOTES, 'UTF-8'); // Display name if no image ?></span>
                    <?php endif; ?>

                    <?php if ($sponsor->isLinkValid) : ?>
                        </a>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>
        
        <!-- Optional: Add Pagination -->
        <div class="swiper-pagination"></div>

        <!-- Optional: Add Navigation -->
        <div class="swiper-button-prev"></div>
        <div class="swiper-button-next"></div>

        <!-- Optional: Add Scrollbar -->
        <div class="swiper-scrollbar"></div>
    </div>
</div>

<?php
// Add extra CSS for the slider
$extraStyle = '';
$extraStyle .= '#scs-sponsors-slider-'.$module->id.' .swiper-button-prev, #scs-sponsors-slider-'.$module->id.' .swiper-button-next { color: '.$params->get('arrowsColor', '#FFFFFF').'; }';
$extraStyle .= '#scs-sponsors-slider-'.$module->id.'.scs-sponsors-tmpl-slider .swiper-pagination-bullet-active { background-color: '.$params->get('arrowsColor', '#FFFFFF').'; }';
$helper->addExtraCSS($extraStyle);

// Add the extra script to the document
$swiperSettings = json_encode([
    'rewind' => $params->get('sliderLoop', 1),
    'speed' => $params->get('sliderSpeed', 1000),
    'pagination' => [
        'enabled' => $params->get('sliderPagination', 1),
    ],
    'navigation' => [
        'enabled' => $params->get('sliderNavigation', 1),
    ],
    'breakpoints' => [
        '1024' => [
            'slidesPerView' => $params->get('itemsOnDesktop', 5),
        ],
        '768' => [
            'slidesPerView' => $params->get('itemsOnTablet', 3),
        ],
    ],
    'scrollbar' => [
        'enabled' => $params->get('sliderScrollbar', 0),
    ],

]);
$extraScript = '';
$extraScript .= 'document.addEventListener("DOMContentLoaded", function() {'."\r\n";
$extraScript .= '  initSlider('.$swiperSettings.');'."\r\n";
$extraScript .= '});'."\r\n";
$helper->addExtraScript($extraScript);
?> 
